import { Subscription } from "../Common";
import { LifeCycleEvent } from "../Common/LifeCycle";
import type { Path, PathValue } from "./DotPath";
import type { BaseStoreClass, BaseStoreImpl, PatchOperationFunction, PatchOperationObject, StoreAction, StoreActionWithSubscriptions, WatchFunction } from "./StoreTypes";
import { ClassStoreSymbol } from "./StoreUtils";
import type { StoreMeta } from "./Types";
declare type HotReloadChange<T> = {
    added: T;
    removed: T;
};
declare type HotReloadChanges = {
    actions: HotReloadChange<StoreMeta['actions']>;
    getters: HotReloadChange<StoreMeta['getters']>;
    state: HotReloadChange<StoreMeta['stateKeys']>;
    hasChanges(): boolean;
};
export declare class BaseStore<TStore, TState> implements BaseStoreImpl<TStore, TState> {
    #private;
    [ClassStoreSymbol]: any;
    private __scope;
    private __storeMeta;
    private __getters;
    private __actions;
    private __lifecycleHooks;
    private __extensions;
    private __originalState;
    private __state;
    private __stateWatcherFuncs;
    private __stateWatchHandles;
    __handlers: Subscription;
    __actionHandlers: StoreActionWithSubscriptions<TStore, TState>[];
    constructor();
    __preBooting(): void;
    __bootStore(): void;
    /**
     * Reset our state back to the original values defined in `get state()`
     */
    $reset(): void;
    /**
     * Access the watcher functions for each state key
     *
     * @template TState
     * @returns {{[K in keyof TState]: WatchFunction<TState[K]>}}
     */
    get $watch(): {
        [K in keyof TState]: WatchFunction<TState[K]>;
    };
    /**
     * Quickly access a state value via dot notation string
     *
     * @template TState
     * @param {P} path
     * @param defaultValue
     * @returns {PathValue<TState, P>}
     */
    $getState<P extends Path<TState>>(path: P, defaultValue?: any): PathValue<TState, P>;
    private __setState;
    /**
     * Apply a patch operation to the state
     *
     * @example
     * ```
     *  store.$patch({myStateValue: 'a new value', anotherStateValue: 'another new value'});
     *  store.$patch((state) => {
     *      state.myStateValue = 'a new value';
     *      state.anotherStateValue = 'another new value';
     *  });
     * ```
     *
     * @template TState
     * @param {PatchOperationFunction<TState>} patchOperation
     */
    $patch(patchOperation: PatchOperationFunction<TState>): void;
    $patch(patchOperation: PatchOperationObject<TState>): void;
    /**
     * Subscribe to action calls
     *
     * @template TStore
     * @template TState
     * @param {(context: StoreAction<TStore, TState>) => void} actionHandler
     * @returns {() => void}
     */
    $onAction<K extends keyof TStore>(actionHandler?: (context: StoreAction<TStore, TState>) => void): () => void;
    __addExtensions(extensions: {
        [key: string]: any;
    }[]): void;
    __addExtension(extension: {
        [key: string]: any;
    }): void;
    __getHook(event: LifeCycleEvent): (() => void | PromiseLike<void>) | (() => void | PromiseLike<void>) | (() => void | PromiseLike<void>) | (() => void | PromiseLike<void>);
    private __wrapHookCall;
    __callHook(event: LifeCycleEvent): void | PromiseLike<void>;
    __checkForHotReloadChanges(newMeta: StoreMeta): HotReloadChanges;
    __processHotReloadChanges(changes: HotReloadChanges, newModule: any, newMeta: StoreMeta): boolean;
}
export declare function Store<TStore, TState>(): BaseStoreClass<TStore, TState>;
export {};
