import { App } from "@vue/runtime-core";
import type { StoreMeta, StoreType } from "./Types";
export declare class StoreManagerInstance {
    private app;
    private didInstantiateStores;
    /**
     * Holds store Class Name -> Store Instance
     * @type {{[p: string]: StoreType}}
     */
    stores: {
        [key: string]: StoreType;
    };
    /**
     * Holds store Class Name -> Store Module
     * @type {{[p: string]: any}}
     */
    storeModules: {
        [key: string]: any;
    };
    /**
     * Holds store Class Name -> Store Meta
     * @type {{[p: string]: StoreMeta}}
     */
    storeMeta: {
        [key: string]: StoreMeta;
    };
    /**
     * Holds a reference of Binding -> Class Name for quick lookup
     * @type {{[p: string]: string}}
     */
    storeBindingToClassName: {
        [key: string]: string;
    };
    private extensions;
    /**
     * The call to this method is transformed by the vite plugin
     * It will automatically add the store loader `import.meta.glob('', {eager:true})` call as a parameter
     *
     * The end developer just needs to use `app.use(StoreManager.boot())`
     *
     * @returns {{install: (app: App) => void}}
     */
    boot(): {
        install: (app: App) => void;
    };
    private bootFromLoader;
    private callLifeCycleHandlers;
    private loadStoresFromLoader;
    private prepareStore;
    private loadStore;
    private addExtensions;
    extend(extensionFunc: () => {
        [key: string]: any;
    }): void;
    /**
     * We have to compromise... we can only handle hot reloads for
     * store meta or individual store modules.... however,
     * It seems like when we use the meta's lazy import module
     * function, it fetches the latest store version....
     * Just means we have to process all stores on hot reload :|
     */
    loaderReloaded(storesMeta: StoreMeta[]): void;
}
declare const storeManager: StoreManagerInstance;
export default storeManager;
