import type { WritableComputedRef } from "@vue/reactivity";
import { LifeCycleEvent } from "../Common/LifeCycle";
import type { BaseStore } from "./Store";
interface BaseStorePublic {
    vueBinding: string;
    __storeMeta: StoreMeta;
    __getters: {
        [key: string]: StoreGetterInfo;
    };
    __actions: {
        [key: string]: (...args: any[]) => any;
    };
    __extensions: StoreExtensionDefinitions;
}
export declare type StoreType = {
    [K in keyof typeof BaseStore['prototype']]: K extends keyof BaseStorePublic ? never : typeof BaseStore['prototype'][K];
} & BaseStorePublic;
export declare type StoreMetaAction = {
    name: string;
    params: StoreMetaAction[];
    lifeCycleEventHandler: LifeCycleEvent | undefined;
};
export declare type StoreMetaActionParam = {
    name: string;
    defaultValue: string;
    type: string;
};
export declare type StoreMetaGetter = {
    n: string;
    c: boolean;
};
export declare type LifeCycleHooks = {
    [LifeCycleEvent.BeforeAll]?: () => void | PromiseLike<void>;
    [LifeCycleEvent.OnInit]?: () => void | PromiseLike<void>;
    [LifeCycleEvent.OnDispose]?: () => void | PromiseLike<void>;
    [LifeCycleEvent.AfterAll]?: () => void | PromiseLike<void>;
};
export declare type StoreMeta = {
    className: string;
    importPath: string;
    exportName: string;
    vueBinding: string;
    stateKeys: string[];
    getters: StoreMetaGetter[];
    actions: StoreMetaAction[];
    lifeCycleHandlers: {
        [key: string]: LifeCycleEvent;
    };
    module: () => {
        [key: string]: {
            [key: string]: any;
        };
    };
};
export declare type StoreLoaderModule = {
    stores: StoreMeta[];
};
export declare enum MutationType {
    Direct = "direct",
    PatchObject = "patch object",
    PatchFunction = "patch function"
}
export declare type StoreGetterComputedInfo = {
    type: 'computed';
    value: WritableComputedRef<any>;
};
export declare type StoreGetterRegularInfo = {
    type: 'function';
    value: () => any;
};
export declare type StoreGetterInfo = StoreGetterComputedInfo | StoreGetterRegularInfo;
export declare type StoreExtensionDefinitions = {
    getters: {
        [key: string]: () => any;
    };
    actions: {
        [key: string]: () => any;
    };
    properties: {
        [key: string]: any;
    };
};
export declare type StoreGettersList = {
    [key: string]: StoreGetterInfo;
};
export declare type StoreActionsList = {
    [key: string]: (...args: any[]) => any;
};
export {};
