import ts from "typescript";
import { ActionMeta } from "./ActionMeta";
export declare class StoreMeta {
    /**
     * The absolute path to the store file
     */
    absFilePath: string;
    /**
     * The relative path of the store file, for ex, if importing in /src/stores/, and our file is at /src/stores/MyStore.ts, this will be MyStore.ts
     */
    relStoreFilePath: string;
    /**
     * The relative import path from Stores/.generated/StoreLoader.ts to the store location
     * @type {string}
     */
    loaderImportPath: string;
    /**
     * The name of the store file
     */
    name: string;
    /**
     * The name of the class that extends Store
     */
    className?: string;
    /**
     * This will hold the name of our store export `export const store = new MyStore();`
     */
    exportName?: string;
    /**
     * If the dev defined `public static vueBinding = 'x';` in their store, this will hold that value
     */
    vueBinding?: string;
    actions: ActionMeta[];
    /**
     * Method name -> handler type
     * @type {{[p: string]: string}}
     */
    lifeCycleHandlers: {
        [key: string]: string;
    };
    stateKeys: string[];
    getters: {
        n: string;
        c: boolean;
    }[];
    stateObj: ts.ObjectLiteralExpression;
    constructor(file: ts.SourceFile);
    isValid(): boolean;
    finalize(): this;
    private formatVueBinding;
    metaObject(includeImport?: boolean): {
        className: string;
        importPath: string;
        exportName: string;
        vueBinding: string;
        stateKeys: string[];
        getters: {
            n: string;
            c: boolean;
        }[];
        lifeCycleHandlers: {
            [key: string]: string;
        };
        actions: any;
        module: import("../Builders/Object").UnwrappableNode;
    };
    setStateObject(stateObj: ts.ObjectLiteralExpression): void;
    addGetter(member: ts.GetAccessorDeclaration): void;
    addLifeCycleHandler(method: ts.MethodDeclaration, lifeCycleEvent: string): void;
}
