"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ActionMeta = void 0;
const typescript_1 = __importDefault(require("typescript"));
const LifeCycle_1 = require("../../Common/LifeCycle");
const Modifiers_1 = require("../AstHelpers/Modifiers");
const ErrorMessages_1 = require("../ErrorMessages");
const TS_1 = require("../TS");
class ActionMeta {
    constructor(method, linter, store) {
        var _a;
        /**
         * The name of the method
         * @type {string}
         */
        Object.defineProperty(this, "name", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        /**
         * The parameters of the method
         * @type {any[]}
         */
        Object.defineProperty(this, "params", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: []
        });
        /**
         * If we defined a lifecycle decorator on the method, we'll return it here
         *
         * @type {LifeCycleEvent}
         */
        Object.defineProperty(this, "lifeCycleEventHandler", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        /**
         * Typescript AST for the method
         * @type {ts.MethodDeclaration}
         * @private
         */
        Object.defineProperty(this, "method", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        /**
         * Typescript AST for the method signature
         * @type {ts.Signature}
         * @private
         */
        Object.defineProperty(this, "signature", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.method = method;
        this.name = method.name.text;
        this.signature = TS_1.TS.typeChecker.getSignatureFromDeclaration(this.method);
        if ((_a = method.modifiers) === null || _a === void 0 ? void 0 : _a.length) {
            for (let lifeCycleEvent of Object.values(LifeCycle_1.LifeCycleEvent)) {
                if ((0, Modifiers_1.hasDecorator)(method, lifeCycleEvent)) {
                    if (this.lifeCycleEventHandler) {
                        linter.error(ErrorMessages_1.errorMessages.lifecycle.multipleLifeCycleHandlersDefined(this.name, store.className, this.lifeCycleEventHandler), method);
                        break;
                    }
                    store.addLifeCycleHandler(this.method, lifeCycleEvent);
                    this.lifeCycleEventHandler = lifeCycleEvent;
                }
            }
        }
        for (let parameter of this.signature.parameters) {
            let defaultValue = undefined;
            if (typescript_1.default.isParameter(parameter.valueDeclaration)) {
                if (parameter.valueDeclaration.initializer) {
                    defaultValue = parameter.valueDeclaration.initializer.getText();
                }
            }
            this.params.push({
                name: parameter.name,
                type: TS_1.TS.typeChecker.typeToString(TS_1.TS.typeChecker.getTypeAtLocation(parameter.valueDeclaration)),
                defaultValue,
            });
        }
    }
    toJSON() {
        return {
            name: this.name,
            params: this.params,
            lifeCycleEventHandler: this.lifeCycleEventHandler,
        };
    }
}
exports.ActionMeta = ActionMeta;
//# sourceMappingURL=ActionMeta.js.map